<?php
/**
 * Interface: for using Wordpress options
 */
namespace EwTools\Interfaces\Storage;

/**
 * WpOptionsInterface.php
 *
 * @link    http://infomaker.se
 * @package EwTools\Interfaces\Storage
 * @since   EwTools\Interfaces\Storage 0.1
 */

interface WpOptionsInterface {
	
	/**
	 * Add data to document-database
	 *
	 * @see   add_option()
	 *
	 * @param string $option
	 * @param mixed  $value
	 * @param bool   $autoload
	 *
	 * @since 0.1
	 * @return bool
	 */
	public static function add( $option, $value, $autoload = true );
	
	/**
	 * Add global data to document-database
	 *
	 * @see   add_network_option()
	 *
	 * @param int    $network_id
	 * @param string $option
	 * @param mixed  $value
	 *
	 * @since 0.1
	 * @return bool
	 */
	public static function addGlobal( $network_id, $option, $value );
	
	/**
	 * Retrieve data from document-database
	 *
	 * @see   get_option()
	 *
	 * @param string $option
	 * @param mixed  $default
	 *
	 * @since 0.1
	 * @return mixed
	 */
	public static function get( $option, $default = false );
	
	/**
	 * Retrieve global data from document-database
	 *
	 * @see   get_network_option()
	 *
	 * @param int    $network_id
	 * @param string $option
	 * @param bool   $default
	 *
	 * @since 0.1
	 * @return mixed
	 */
	public static function getGlobal( $network_id, $option, $default = false );
	
	/**
	 * Remove data from document-database
	 *
	 * @see   delete_option()
	 *
	 * @param string $option
	 *
	 * @since 0.1
	 * @return bool
	 */
	public static function remove( $option );
	
	/**
	 * Remove global data from document-database
	 *
	 * @see   delete_network_option()
	 *
	 * @param int    $network_id
	 * @param string $option
	 *
	 * @since 0.1
	 * @return bool
	 */
	public static function removeGlobal( $network_id, $option );
	
	/**
	 * Update data on document-database
	 *
	 * @see   update_option()
	 *
	 * @param string $option
	 * @param mixed  $value
	 * @param bool   $autoload
	 *
	 * @since 0.1
	 * @return bool
	 */
	public static function update( $option, $value, $autoload = true );
	
	/**
	 * Update global data on document-database
	 *
	 * @see   update_network_option()
	 *
	 * @param int    $network_id
	 * @param string $option
	 * @param mixed  $value
	 *
	 * @since 0.1
	 * @return mixed
	 */
	public static function updateGlobal( $network_id, $option, $value );
}