<?php
/**
 * Everyware Page meta.
 *
 * Metabox Name: Everyware Page Attributes
 * Description: A handy way of managing everyware-specific meta on pages
 * Version: 0.1
 * Author: Infomaker Scandinavia AB
 * Author URI: http://infomaker.se
 */
namespace EwTools\Metaboxes;

use EwTools\Admin\Metabox;
use EwTools\Handler\Menus;
use EwTools\Models\Everyboard;
use EwTools\Models\Page;
use EwTools\Models\Section;

/**
 * EwPageMeta
 *
 * @link    http://infomaker.se
 * @package EwTools\Metaboxes
 * @since   EwTools\Metaboxes\EwPageMeta 0.1
 */
class EwPageMeta extends Metabox  {
    /**
     * Contains the context within the screen where the boxes should display.
     * Page edit screen contexts include 'normal', 'side' and 'advanced'. Default 'side'.
     *
     * @var string
     */
    protected static $box_position = 'normal';
    
    /**
     * Contains the priority within the context where the boxes
     * should show ('high', 'low', 'core', 'sorted', 'default'). Default 'default'.
     *
     * @var string
     */
    protected static $box_priority = 'core';
    
    /**
     * postmeta id
     *
     * @see Metabox::$postmeta_id
     * @var string
     */
    public static $postmeta_id = 'ew_page_meta_box';
    
    /**
     * metabox id
     *
     * @see Metabox::$meta_box_id
     * @var string
     */
    protected $meta_box_id = 'ew-page-meta-box';
    
    /**
     * Twig-template to use
     *
     * @var string
     */
    protected $template_path = '@tools/metaboxes/page-meta';
    
    /**
     * Metabox fields:
     * Contains fields to add and manage a page-specific subheader
     *
     * @var array
     */
    protected $fields = [
        'title'   => '',
        'description' => '',
        'noindex' => false,
        'nofollow' => false,
        'menu'    => '',
        'section' => '',
        'logo'    => '',
        'use_parent'  => false,
        'use_submenu' => false,
        'query'   => ''
    ];
    
    /**
     * PageSubHead constructor.
     *
     * @param string $title
     *
     * @since 0.1
     */
    public function __construct( $title = 'Page Subhead' ) {
        $this->setMetaboxData(__FILE__);
        parent::__construct( $title );
    }
    
    /**
     * Render the metabox form
     *
     * @param string $view_data
     *
     * @since 0.1
     * @return void
     */
    protected function edit( $view_data ) {
        $connected_board = Page::current()->getMeta('everyboard_id', null);
        
        $this->view('form', array_replace_recursive([
            'menus' => Menus::toSelect($view_data['menu']['value']),
            'sections' => Section::toSelect($view_data['section']['value']),
            'connected_board' => $connected_board ? Everyboard::createFromId( $connected_board ) : null
        ], $view_data));
    }
}