<?php namespace EwTools\Twig;

use EwTools\Storage\Cache;
use SplFileInfo;
use Twig_Error;
use Twig_Loader_Chain;
use Twig_Loader_Filesystem;

/**
 * FilesystemLoader
 *
 * @link    http://infomaker.se
 * @package EwTools\Twig
 * @since   EwTools\Twig\FilesystemLoader 0.1
 */
class FilesystemLoader extends Twig_Loader_Filesystem {
    
    /**
     * Time in seconds to cache the output if cache is set to true
     *
     * @var int
     */
    private $cache_time = 86400;
    
    /**
     * Add suffix so we don't have to delete it in deploy every time
     *
     * @var string
     */
    private $cache_key = 'everytwig_paths_cache_' . GIT_COMMIT;
    
    /**
     * Adds the folders containing the files to be loaded
     *
     * @param string $folder_path
     * @param string $namespace
     * @param array  $exclude
     *
     * @throws Twig_Error
     * @since 0.1
     * @return void
     */
    public function addPathAndSubfolders( $folder_path, $namespace = Twig_Loader_Filesystem::MAIN_NAMESPACE, $exclude = [] ) {
        if ( ! file_exists( $folder_path ) ) {
            throw new Twig_Error("{$folder_path} does not exist" );
        }
        $cache_key = $this->getPathCacheKey($namespace);
        $paths = Cache::get($cache_key, []);
        
        if ( empty($paths) ) {
            $dir = PathFilter::setupFromPath( $folder_path, $exclude );
            $paths = [];
            foreach ( $dir->filtered() as $d ) {
                if ( $d instanceof SplFileInfo) {
                    $paths[] = str_replace('//','/',$d->getPath());
                }
            }
        
            $paths = array_unique($paths);
            Cache::set($cache_key, $paths, $this->cache_time);
        }
        
        foreach ( $paths as $path ) {
            $this->addPath( $path, $namespace );
        }
    }
    
    /**
     * No documentation yet
     * @todo Add documentation
     *
     * @param array $array
     *
     * @since 0.1
     * @return Twig_Loader_Chain
     */
    public function getChain( array $array ) {
        return new Twig_Loader_Chain( $array );
    }
    
    /**
     *
     *
     * @param $namespace
     *
     * @since 1.0.0
     * @return string
     */
    private function getPathCacheKey( $namespace ) {
        return "{$this->cache_key}_{$namespace}";
    }
    
    /**
     * Set cache time in seconds
     *
     * @param $time
     *
     * @since 1.0.0
     * @return void
     */
    public function setCacheTime($time) {
        $this->cache_time = $time;
    }
}